@@ -1,4 +1,4 @@
-/* $Id: proctime.h,v 1.26 2004/06/09 18:52:20 bdejean Exp $ */
+/* $Id: proctime.h,v 1.27 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -88,16 +88,6 @@ void glibtop_init_proc_time_s (glibtop *server);
 void glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_time [];
-extern const unsigned glibtop_types_proc_time [];
-extern const char *glibtop_labels_proc_time [];
-extern const char *glibtop_descriptions_proc_time [];
-
-#endif
 
 G_END_DECLS
 
