@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procuid.c,v 1.10 2003/10/19 16:55:46 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -36,88 +34,94 @@ static const unsigned long _glibtop_sysdeps_proc_uid_psinfo =
 (1L << GLIBTOP_PROC_UID_TTY) + (1L << GLIBTOP_PROC_UID_PRIORITY) +
 (1L << GLIBTOP_PROC_UID_NICE);
 static const unsigned long _glibtop_sysdeps_proc_uid_prcred =
+#if LIBGTOP_VERSION_CODE >= 1001002
 #ifdef HAVE_PROCFS_H
 (1L << GLIBTOP_PROC_UID_GROUPS) +
 #endif
 (1L << GLIBTOP_PROC_UID_SUID) + (1L << GLIBTOP_PROC_UID_SGID) +
 (1L << GLIBTOP_PROC_UID_NGROUPS);
+#else
+0;
+#endif
 /* Init function. */
 
-int
+void
 glibtop_init_proc_uid_s (glibtop *server)
 {
-    server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid_psinfo +
-	_glibtop_sysdeps_proc_uid_prcred;
-
-    return 0;
+	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid_psinfo +
+	   			   _glibtop_sysdeps_proc_uid_prcred;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid)
 {
-    struct prcred prcred;
+#if LIBGTOP_VERSION_CODE >= 1001002
+	struct prcred prcred;
+#endif
 #ifdef HAVE_PROCFS_H
-    struct psinfo psinfo;
-    gid_t groups[GLIBTOP_MAX_GROUPS];
+	struct psinfo psinfo;
+#if LIBGTOP_VERSION_CODE >= 1001002
+	gid_t groups[GLIBTOP_MAX_GROUPS];
+#endif
 #else
-    struct prpsinfo psinfo;
-    gid_t groups[1];	/* dummy for consistent function prototype */
+	struct prpsinfo psinfo;
+	gid_t groups[1];	/* dummy for consistent function prototype */
 #endif
-    int retval;
 
-    memset (buf, 0, sizeof (glibtop_proc_uid));
+	memset (buf, 0, sizeof (glibtop_proc_uid));
 
-    retval = glibtop_get_proc_data_psinfo_s (server, &psinfo, pid);
-    if (retval) return retval;
+	if (glibtop_get_proc_data_psinfo_s (server, &psinfo, pid))
+		return;
 
-    buf->euid = psinfo.pr_euid;
-    buf->uid = psinfo.pr_uid;
-    buf->egid = psinfo.pr_egid;
-    buf->gid = psinfo.pr_gid;
+	buf->euid = psinfo.pr_euid;
+	buf->uid = psinfo.pr_uid;
+	buf->egid = psinfo.pr_egid;
+	buf->gid = psinfo.pr_gid;
 
-    buf->pid = psinfo.pr_pid;
-    buf->ppid = psinfo.pr_ppid;
+	buf->pid = psinfo.pr_pid;
+	buf->ppid = psinfo.pr_ppid;
 #ifdef HAVE_PROCFS_H
-    buf->pgrp = psinfo.pr_pgid;
+	buf->pgrp = psinfo.pr_pgid;
 #else
-    buf->pgrp = psinfo.pr_pgrp;
+	buf->pgrp = psinfo.pr_pgrp;
 #endif
 
-    buf->session = psinfo.pr_sid;
-    buf->tty = psinfo.pr_ttydev;
+	buf->session = psinfo.pr_sid;
+	buf->tty = psinfo.pr_ttydev;
 
 #ifdef HAVE_PROCFS_H
-    buf->priority = psinfo.pr_lwp.pr_pri;
-    buf->nice = psinfo.pr_lwp.pr_nice - NZERO;
+	buf->priority = psinfo.pr_lwp.pr_pri;
+	buf->nice = psinfo.pr_lwp.pr_nice - NZERO;
 #else
-    buf->priority = psinfo.pr_pri;
-    buf->nice = psinfo.pr_nice - NZERO;
+	buf->priority = psinfo.pr_pri;
+	buf->nice = psinfo.pr_nice - NZERO;
 #endif
 
-    buf->flags = _glibtop_sysdeps_proc_uid_psinfo;
+	buf->flags = _glibtop_sysdeps_proc_uid_psinfo;
 
-    retval = glibtop_get_proc_credentials_s(server, &prcred, groups, pid);
-    if (retval) return retval;
+#if LIBGTOP_VERSION_CODE >= 1001002
+	if(glibtop_get_proc_credentials_s(server, &prcred, groups, pid))
+		return;
 
-    buf->suid = prcred.pr_suid;
-    buf->sgid = prcred.pr_sgid;
-    buf->ngroups = (prcred.pr_ngroups <= GLIBTOP_MAX_GROUPS) ?
-	prcred.pr_ngroups : GLIBTOP_MAX_GROUPS;
+	buf->suid = prcred.pr_suid;
+	buf->sgid = prcred.pr_sgid;
+	buf->ngroups = (prcred.pr_ngroups <= GLIBTOP_MAX_GROUPS) ?
+	   		prcred.pr_ngroups : GLIBTOP_MAX_GROUPS;
 
 #ifdef HAVE_PROCFS_H
-    if(sizeof(int) == sizeof(gid_t))
-	memcpy(buf->groups, &groups, buf->ngroups * sizeof(gid_t));
-    else {
-	int i;
+	if(sizeof(int) == sizeof(gid_t))
+	   	memcpy(buf->groups, &groups, buf->ngroups * sizeof(gid_t));
+	else
+	{
+	   	int i;
 
-	for(i = 0; i < buf->ngroups; ++i)
-	    buf->groups[i] = groups[i];
-    }
+		for(i = 0; i < buf->ngroups; ++i)
+		   	buf->groups[i] = groups[i];
+	}
+#endif
 #endif
 
-    buf->flags |= _glibtop_sysdeps_proc_uid_prcred;
-
-    return 0;
+	buf->flags += _glibtop_sysdeps_proc_uid_prcred;
 }
